;; Generated package description from csv-mode.el  -*- no-byte-compile: t -*-
(define-package "csv-mode" "1.21" "Major mode for editing comma/char separated values" '((emacs "27.1") (cl-lib "0.5")) :commit "d10d68c382e17960fc9aaef072fd18a23ea92a86" :url "https://elpa.gnu.org/packages/csv-mode.html" :authors '(("\"Francis J. Wright\"" . "F.J.Wright@qmul.ac.uk")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("convenience"))
